@@ -1,5 +1,5 @@
 /* error.h
- * Copyright (C) 2004, 2005 Sylvain Cresto <sylvain.cresto@tiscali.fr>
+ * Copyright (C) 2004, 2005 Sylvain Cresto <scresto@gmail.com>
  *
  * This file is part of graveman!
  *
@@ -28,13 +28,16 @@
 #define _ERR_NO_CD  11
 #define _ERR_BUF_EMPTY 12
 #define _ERR_INAPPROPRIATE_DATA 13
-#define _ERR_INAPROPRIATE_MODE 14
+#define _ERR_INAPPROPRIATE_MODE 14
 #define _ERR_BAD_RECORDER 15
 #define _ERR_READCD 16
 #define _ERR_MKISOFS 17
 #define _ERR_INCOMPATIBLE_MEDIUM 18
 #define _ERR_CANNOT_BLANK 19
 #define _ERR_SOX 20
+#define _ERR_ALREADY_FORMAT 21
+#define _ERR_CONFIGURATION 22
+#define _ERR_GROWISOFS 23
 #define _ERR_UNKNOWN_ERROR 100
 
 /*
