@@ -1,5 +1,5 @@
 /* matos.c
- * Copyright (C) 2004, 2005 Sylvain Cresto <sylvain.cresto@tiscali.fr>
+ * Copyright (C) 2004, 2005 Sylvain Cresto <scresto@gmail.com>
  *
  * This file is part of graveman!
  *
@@ -96,6 +96,28 @@ void free_drives(gboolean Aremovemanu)
   if (g_slist_length(Glistdrives)==0) Glistdrives = NULL;
 }
 
+void get_current_matos(gboolean *Areadcd, gboolean *Awritecdr, gboolean *Awritecdrw, gboolean *Areaddvd, gboolean *Awritedvd)
+{
+  GSList *Lcur;
+  Tdriveinfo *Ldrive;
+
+  if (Areadcd) *Areadcd = FALSE;
+  if (Awritecdr) *Awritecdr = FALSE;
+  if (Awritecdrw) *Awritecdrw = FALSE;
+  if (Areaddvd) *Areaddvd = FALSE;
+  if (Awritedvd) *Awritedvd = FALSE;
+
+  for (Lcur = Glistdrives; Lcur; Lcur = g_slist_next(Lcur)) { 
+    Ldrive = (Tdriveinfo *)Lcur->data;
+
+    if (DRIVE_READER(Ldrive) && Areadcd) *Areadcd = TRUE;
+    if (DRIVE_WRITER(Ldrive) && Awritecdr) *Awritecdr = TRUE; 
+    if (DRIVE_CDRW_WRITER(Ldrive) && Awritecdrw) *Awritecdrw = TRUE; 
+    if (DRIVE_DVDREADER(Ldrive) && Areaddvd) *Areaddvd = TRUE;
+    if (DRIVE_DVDWRITER(Ldrive) && Awritedvd) *Awritedvd = TRUE;
+  }
+}
+
 void insert_or_update_drive(gchar *Adev, gchar *Amarque, gchar *Amodel, gchar *Aquoi, Tsearchdrive *Adrivedesc)
 {
   /* on commence par construire l'identifiant */
@@ -314,7 +336,7 @@ _DEB("ici LDST => %s\n", Ldst);
   }
   g_hash_table_insert(Ahash, "iso", &Liso); /* image iso */
   if (Lstatus && *Labort==FALSE) {
-    Lextrapara = make_image_getextrapara(Ahash);
+    Lextrapara = make_image_getextrapara(Ahash, "data");
     g_hash_table_insert(Ahash, "extrapara", &Lextrapara); /* parametres supplementaires */
     Lstatus = make_iso(Ahash, Aerror);
     g_hash_table_remove(Ahash, "extrapara");
@@ -451,6 +473,60 @@ extern Tdriveinfo *get_drive_cmb(GtkComboBox *Acombo)
   return (Tdriveinfo *) g_slist_nth_data(Glistdrives, Lvalue);
 }
 
+/* operation gravure dcd de donnee */
+gboolean burn_dvddata(GHashTable *Ahash, GError **Aerror)
+{
+  gint Ltodo = gtk_spin_button_get_value(GTK_SPIN_BUTTON(g_hash_table_lookup(Ahash, "nbrdvddata")));
+  gboolean Lsimul = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(g_hash_table_lookup(Ahash, "dvddatasimul")));
+  GtkEntry *Lgraveuriso = GTK_ENTRY(g_hash_table_lookup(Ahash, "dstdvddatabtnvalue"));
+  GtkWidget *Lgraveur = g_hash_table_lookup(Ahash, "dstdvddatacombo");
+  gint Ldone = 1;
+  gchar *Ldst = get_combo_value(Lgraveur);
+  gchar *Ltmpdir = NULL;
+  gchar *Lextrapara = NULL;
+  gchar *Liso = NULL;
+  gboolean Loperationstatus = FALSE;
+  gboolean Lstatus;
+
+  g_hash_table_insert(Ahash, "todo", &Ltodo); /* a faire */
+  g_hash_table_insert(Ahash, "done", &Ldone); /* fais */
+  g_hash_table_insert(Ahash, "operationstatus", &Loperationstatus); /* resultat de l'operation */
+  g_hash_table_insert(Ahash, "gerror", Aerror);  /* pointeur retour des erreurs */
+  g_hash_table_insert(Ahash, "tmpdir", &Ltmpdir); /* repertoire temporraire */
+
+  /* on retourne dans ltmp le nom du repertoire temporraire utilise pour
+   * l'operation */
+  Lstatus = preparedata(Ahash, Aerror);
+_DEB("ici LDST => %s\n", Ldst);
+
+  Lextrapara = make_image_getextrapara(Ahash, "dvddata");
+  g_hash_table_insert(Ahash, "extrapara", &Lextrapara); /* parametres supplementaires */
+  if (strcmp(Ldst, "iso")) {
+    if (Lsimul) Ltodo++; /* 1 pour la simulation */
+
+    Lstatus = burn_dvd(Ahash, Aerror);
+
+  } else {
+    Liso = _FILENAME(gtk_entry_get_text(Lgraveuriso));
+    Ltodo = 1;
+    g_hash_table_insert(Ahash, "iso", &Liso); /* image iso */
+    Lstatus = make_iso(Ahash, Aerror);
+    g_hash_table_remove(Ahash, "iso");
+    g_free(Liso);
+  }
+  g_hash_table_remove(Ahash, "extrapara");
+  g_free(Lextrapara);
+
+  deltempdir(Ltmpdir);
+
+  g_hash_table_remove(Ahash, "todo");
+  g_hash_table_remove(Ahash, "done"); 
+  g_hash_table_remove(Ahash, "tmpdir"); g_free(Ltmpdir);
+  g_hash_table_remove(Ahash, "operationstatus"); 
+  g_hash_table_remove(Ahash, "gerror");
+
+  return Lstatus;
+}
 
 /*
  * vim:et:ts=8:sts=2:sw=2
